/*--------- DS18B20 displayed by 4bit segment module-----------
Function: Display temperature by UART and 4bit 74HC595 Segment
Board: STC32G12K128
Main Fosc: 22.1184 MHz
Baud rate: 9600 bps
Connect: 
DS18B20: DQ --> P23
74HC595: SCLK --> P22
				 RCLK --> P21
				 DIO --> P20
Author: Jin-Lei Li
Email: lijinlei0907@163.com
Date: Feb. 19, 2024
Ref: https://www.stcaimcu.com/forum.php?mod=viewthread&tid=323&extra=page%3D1
Ref: UART section in STC32 series datasheet
------------------------------*/

#include <STC32G.h>
#include <intrins.h>
#include "configurations.h"
#include "Delay.h"
#include "DS18B20.h"
#include "4bit_Segment_Module.h"

/*-------------- GPIO initialize ------------------*/
void GPIO_Init()
{
	P0M1 = 0x00;   P0M0 = 0x00;
  P1M1 = 0x00;   P1M0 = 0x00;
  P2M1 = 0x00;   P2M0 = 0x00;
  P3M1 = 0x00;   P3M0 = 0x00;
  P4M1 = 0x00;   P4M0 = 0x00;
  P5M1 = 0x00;   P5M0 = 0x00;
	P6M1 = 0x00;   P6M0 = 0x00;
  P7M1 = 0x00;   P7M0 = 0x00;
}
/*----------- Display temperature ----------------*/
void Display()
{
	u8 ms = 2; // number of Delay_ms
	u16 val;
	u16 shi,ge,xiaoshu;
  val = Readtemp();
  shi = val/100;
  ge = val/10%10;
  xiaoshu = val%10;
	if( MinusFlag==1 ) // negtive
	{
		SEG_Disp(11,1);					//数码管左边第1位显示正负
		Delay_ms(ms);
		SEG_Disp((u16)(shi),2);					//数码管左边第2位显示十位
		Delay_ms(ms);
		SEG_Disp((u16)(ge),3);					//数码管左边第3位显示个位
		Delay_ms(ms);
		SEG_Disp(13,3);					//数码管左边第3位显示小数点
		Delay_ms(ms);
		SEG_Disp((u16)(xiaoshu),4);					//数码管左边第4位显示小数
		//Delay_ms(1); // 避免最后一位过亮
	}
	else // MinusFlag==0, positive
	{
		SEG_Disp(10,1);					//数码管左边第1位显示正负
		Delay_ms(ms);
		SEG_Disp((u16)(shi),2);					//数码管左边第2位显示十位
		Delay_ms(ms);
		SEG_Disp((u16)(ge),3);					//数码管左边第3位显示个位
		Delay_ms(ms);
		SEG_Disp(13,3);					//数码管左边第3位显示小数点
		Delay_ms(ms);
		SEG_Disp((u16)(xiaoshu),4);					//数码管左边第4位显示小数
		//Delay_ms(1); // 避免最后一位过亮
	}
}

void main()
{
	EAXFR = 1;				//使能XFR访问
	CKCON = 0x00;			//设置外部数据总线速度最快
	WTST = 0x00;			//设置程序读取等待时间为0个时钟，CPU执行程序速度最快
	GPIO_Init();
	while(1)
	{
		Display();
    //Delay_ms(1); // 避免最后一位过亮
	}
}